import { AggregateEvent, AggregateEventType, AggregateRoot } from '@generic-ui/hermes';
import { PagingManager } from '../../../paging/src/domain/paging.manager';
import { SourceManager } from '../../../source/src/domain/source.manager';
import { VerticalFormation } from '../../../vertical-formation/src/domain/vertical-formation';
import { SummariesManager } from '../../../summaries/src/domain/summaries.manager';
import { SorterManager } from '../../../sorting/src/domain/sorter.manager';
import { FilterManager } from '../../../filter/src/domain/filter.manager';
import { FieldCollection } from '../../../field/src/domain/field-collection';
import { FormationManager } from '../../../formation/src/domain/formation.manager';
import { StructureId } from '../api/global/structure.id';
import { StructureEditSourceItemParams } from '../../../source/src/core/origin/edit/structure.edit-source-item.params';
import { PagingConfig } from '../../../paging/src/api/config/paging-config';
import { ItemEntity } from '../../../source/src/domain/item/item.entity';
import { SortingConfig } from '../../../sorting/src/api/config/sorting-config';
import { FieldId } from '../../../field/src/domain/field/field.id';
import { Sorter } from '../../../sorting/src/domain/sorter';
import { FilterConfig } from '../../../filter/src/api/config/filter.config';
import { QuickFiltersConfig } from '../../../filter/src/api/quick-filter/quick-filters.config';
import { SearchConfig } from '../../../search/src/api/config/search-config';
import { SearchManager } from '../../../search/src/domain/search.manager';
import { SortOrder } from '../../../../composition/src/domain/column/sort/sort-order';
import { SchemaTheme } from '../../../../schema/src/api/theme/schema-theme';
import { FieldConfig } from '../../../field/src/api/config/field.config';
import { FilterTypeId } from '../../../filter/src/domain/type/filter-type.id';
import { FilterId } from '../../../filter/src/api/id/filter.id';
import { UniqueFilterManager } from '../../../filter/src/domain/unique/unique-filter-manager';
import { UniqueValueId } from '../../../filter/src/domain/unique/unique-value-id';
import { RowSelectToggleType } from '../../../formation/src/domain/row-select-toggle-type';
import { RowSelectionMode, RowSelectionType } from '../../../formation/src/api/row-selected/row-selection';
import { ItemEntityId } from '../../../source/src/domain/item/item.entity-id';
import { FormationCustomSelectId } from '../../../formation/src/api/custom/formation.custom-select.id';
import { FormationCustomSelectionConfig } from '../../../formation/src/api/custom/formation.custom-selection.config';
export declare class StructureAggregate extends AggregateRoot<StructureId> {
    private pagingManager;
    private readonly sourceManager;
    private sorterManager;
    private filterManager;
    private searchManager;
    private readonly verticalFormation;
    private fieldCollection;
    private summariesManager;
    private readonly uniqueFilterManager;
    constructor(structureId: StructureId, pagingAggregate: PagingManager, sourceManager: SourceManager, verticalFormation: VerticalFormation, summariesManager: SummariesManager, sorterCollection: SorterManager, filterManager: FilterManager, uniqueFilterManager: UniqueFilterManager, searchManager: SearchManager, fieldCollection: FieldCollection);
    createEvent(): AggregateEventType<AggregateEvent<StructureId>>;
    clearEvents(): void;
    init(): void;
    setVerticalFormationEnabled(enabled: boolean): void;
    getVerticalFormation(): VerticalFormation;
    setSummariesEnabled(enabled: boolean): ReadonlyArray<AggregateEvent<StructureId>>;
    setOrigin(items: Array<any>): ReadonlyArray<AggregateEvent<StructureId>>;
    deleteItem(payload: number | ItemEntityId | Array<number> | Array<ItemEntityId>): void;
    editItem(editParams: StructureEditSourceItemParams): ReadonlyArray<AggregateEvent<StructureId>>;
    setHeight(height: number): void;
    setTheme(theme: SchemaTheme): void;
    setScrollPosition(position: number): void;
    scrollToIndex(index: number): void;
    setSelection(enabled: boolean): void;
    setSelectionMode(mode: RowSelectionMode): void;
    setSelectionType(type: RowSelectionType): void;
    setFormationMatcher(matcher: (item: any) => any): void;
    selectByIndex(indexes: Array<number>): void;
    selectByIds(ids: Array<string>): void;
    /**
     *
     * Doesnt' work
     */
    setSelectedRows(selectedRows: Array<string>): void;
    setSelectionCustomConfig(config: FormationCustomSelectionConfig): void;
    toggleRow(selectedRow: string, type: RowSelectToggleType): void;
    selectCustom(id: FormationCustomSelectId): void;
    selectAll(): void;
    unselectAll(): void;
    getFormation(): FormationManager;
    getPaging(): PagingManager;
    changePaging(config: PagingConfig): void;
    setPaging(paging: PagingManager): void;
    nextPage(): void;
    prevPage(): void;
    changePageSize(pageSize: number): ReadonlyArray<AggregateEvent<StructureId>>;
    getEntities(): Array<ItemEntity>;
    getSource(): SourceManager;
    createFields(fieldConfigs: Array<FieldConfig>): ReadonlyArray<AggregateEvent<StructureId>>;
    setSortingConfig(config: SortingConfig): void;
    toggleSort(fieldId: FieldId): Array<Sorter>;
    setSortOrder(fieldId: FieldId, sortOrder: SortOrder): Array<Sorter>;
    setFilterConfig(config: FilterConfig): void;
    setQuickFiltersConfig(config: QuickFiltersConfig): void;
    toggleFilter(fieldId: FieldId, externalFilterId: string, filterValue: string): Array<AggregateEvent<StructureId>>;
    addFilter(fieldId: FieldId, filterTypeId: FilterTypeId, value: any): void;
    removeAllFilters(): void;
    removeFilter(filterId: FilterId): void;
    setSearchingConfig(config: SearchConfig): void;
    addSearchPhrase(phrase: string): Array<AggregateEvent<StructureId>>;
    removeSearchPhrase(): Array<AggregateEvent<StructureId>>;
    selectAllUniqueFilter(fieldId: FieldId): void;
    selectUniqueFilter(fieldId: FieldId, uniqueValueId: UniqueValueId): void;
    unselectAllUniqueFilter(fieldId: FieldId): void;
    unselectUniqueFilter(fieldId: FieldId, uniqueValueId: UniqueValueId): void;
    private calculateSource;
    private calculateSourceBasedOnVirtualScroll;
    private initTheme;
    private calculateUniqueValues;
    private generateCalculateUniqueValuesAggregateEvent;
    private generateSelectedRowChangedEvent;
}
